@@ -153,30 +153,25 @@ class SoS_ExecutePreprocessor(ExecutePreprocessor):
         self._filename = filename
 
     def _prepare_meta(self, cell):
-        meta = {}
-        run_notebook = re.search(
+        meta = {
+            'use_panel': False,
+            'cell_id': '0',
+            'path': self._filename,
+            'batch_mode': True,
+            'cell_kernel': cell.metadata.kernel
+            }
+        if re.search(
             r'^%sosrun($|\s)|^%sossave($|\s)|^%preview\s.*(-w|--workflow).*$',
-            cell.source, re.MULTILINE)
-        if run_notebook:
+            cell.source, re.MULTILINE):
             meta['workflow'] = self._workflow
-        if re.search(r'^%toc\s/', cell.source, re.MULTILINE):
-            meta['toc'] = self._toc
-        meta['path'] = self._filename
-        meta['use_panel'] = False
-        meta['rerun'] = False
-        # ID is dynamically generated by the frontend and does not exist
-        # in the backend for batch mode
-        meta['cell_id'] = 0
-        meta['batch_mode'] = True
-        meta['cell_kernel'] = cell.metadata.kernel
         return meta
 
-    def run_cell(self, cell, cell_index=0):
+    def run_cell(self, cell, cell_index=0, store_history=True):
         # sos is the additional meta information sent to kernel
         content = dict(
             code=cell.source,
             silent=False,
-            store_history=False,
+            store_history=store_history,
             user_expressions='',
             allow_stdin=False,
             stop_on_error=False,
@@ -266,19 +261,8 @@ class SoS_ExecutePreprocessor(ExecutePreprocessor):
 
         return exec_reply, outs
 
-    def _scan_table_of_content(self, nb):
-        cells = nb.cells
-        TOC = ''
-        for cell in cells:
-            if cell.cell_type == "markdown":
-                for line in cell.source.splitlines():
-                    if re.match('^#+ ', line):
-                        TOC += line + '\n'
-        return TOC
-
     def preprocess(self, nb, *args, **kwargs):
         self._workflow = extract_workflow(nb)
-        self._toc = self._scan_table_of_content(nb)
         return super(SoS_ExecutePreprocessor,
                      self).preprocess(nb, *args, **kwargs)
 
